@@ -222,13 +222,14 @@ class Node(BaseModel, T.Generic[InsertType]):
             conflict_str = custom_on_conflict_str
         elif upsert_given_conflict_on:
             # replace s and variables
-            s, variables = basemodel_to_str(
+            update_s, update_variables = basemodel_to_str(
                 insert,
                 default_replace=True,
                 fields_to_exclude=set(insert.dict(exclude_none=True).keys())
                 - cls.GraphORM.updatable_fields,
             )
-            conflict_str = f"UNLESS CONFLICT ON .{upsert_given_conflict_on} ELSE (UPDATE {cls._model_name} SET {s})"
+            variables.update(update_variables)
+            conflict_str = f"UNLESS CONFLICT ON .{upsert_given_conflict_on} ELSE (UPDATE {cls._model_name} SET {update_s})"
         elif return_conflicting_model_on:
             conflict_str = f"UNLESS CONFLICT ON .{return_conflicting_model_on} ELSE (SELECT {cls._model_name})"
         select_str = f"SELECT model {given_resolver.to_str()}"
